/* Debug Toolbar CSS Reset, adapted from Eric Meyer's CSS Reset */
#plDebug {color:#000;background:#FFF;}
#plDebug, #plDebug div, #plDebug span, #plDebug applet, #plDebug object, #plDebug iframe,
#plDebug h1, #plDebug h2, #plDebug h3, #plDebug h4, #plDebug h5, #plDebug h6, #plDebug p, #plDebug blockquote, #plDebug pre,
#plDebug a, #plDebug abbr, #plDebug acronym, #plDebug address, #plDebug big, #plDebug cite, #plDebug code,
#plDebug del, #plDebug dfn, #plDebug em, #plDebug font, #plDebug img, #plDebug ins, #plDebug kbd, #plDebug q, #plDebug s, #plDebug samp,
#plDebug small, #plDebug strike, #plDebug strong, #plDebug sub, #plDebug sup, #plDebug tt, #plDebug var,
#plDebug b, #plDebug u, #plDebug i, #plDebug center,
#plDebug dl, #plDebug dt, #plDebug dd, #plDebug ol, #plDebug ul, #plDebug li,
#plDebug fieldset, #plDebug form, #plDebug label, #plDebug legend,
#plDebug table, #plDebug caption, #plDebug tbody, #plDebug tfoot, #plDebug thead, #plDebug tr, #plDebug th, #plDebug td {
	margin:0;
	padding:0;
	border:0;
	outline:0;
	font-size:12px;
	line-height:1.5em;
	color:#000;
	vertical-align:baseline;
	background:transparent;
	font-family:sans-serif;
	text-align:left;
}

#plDebug #plDebugToolbar {
	background:#111;
	width:200px;
	z-index:100000000;
	position:fixed;
	top:0;
	bottom:0;
	right:0;
	opacity:0.9;
}

#plDebug #plDebugToolbar small {
	color:#999;
}

#plDebug #plDebugToolbar ul {
	margin:0;
	padding:0;
	list-style:none;
}

#plDebug #plDebugToolbar li {
	border-bottom:1px solid #222;
	color:#fff;
	display:block;
	font-weight:bold;
	float:none;
	margin:0;
	padding:0;
	position:relative;
	width:auto;
}

#plDebug #plDebugToolbar li>a,
#plDebug #plDebugToolbar li>div.contentless  {
	font-weight:normal;
	font-style:normal;
	text-decoration:none;
	display:block;
	font-size:16px;
	padding:10px 10px 5px 25px;
	color:#fff;
}

#plDebug #plDebugToolbar li a:hover {
	color:#111;
	background-color:#ffc;
}

#plDebug #plDebugToolbar li.active {
	background-image:url(indicator.png);
	background-repeat:no-repeat;
	background-position:left center;
	background-color:#333;
	padding-left:10px;	
}

#plDebug #plDebugToolbar li.active a:hover {
	color:#b36a60;
	background-color:transparent;
}

#plDebug #plDebugToolbar li small {
	font-size:12px;
	color:#999;
	font-style:normal;
	text-decoration:none;
	font-variant:small-caps;
}

#plDebug #plDebugToolbarHandle {
	position:fixed;
	background:#fff;
	border:1px solid #111;
	top:30px;
	right:0;
	z-index:100000000;
	opacity:0.75;
}

#plDebug a#plShowToolBarButton {
	display:block;
	height:60px;
	width:60px;
	border-right:none;
	border-bottom:4px solid #fff;
	border-top:4px solid #fff;
	border-left:4px solid #fff;
	color:#fff;
	font-size:10px;
	font-weight:bold;
	text-decoration:none;
	text-align:center;
	text-indent:-999999px;
	background:#000 url(information.gif) no-repeat left center;
	opacity:0.5;
}

#plDebug a#plShowToolBarButton:hover {
	background-color:#000;
	padding-right:6px;
	border-top-color:#FFE761;
	border-left-color:#FFE761;
	border-bottom-color:#FFE761;
	opacity:1.0;
}

#plDebug pre {
	overflow:auto;
    font-family:monospace,serif;
}

#plDebug tr.plDebugOdd {
	background-color:#f5f5f5;
}

#plDebug .panelContent {
	display:none;
	position:fixed;
	margin:0;
	top:0;
	right:200px;
	bottom:0;
	left:0px;
	background-color:#eee;
	color:#666;
	z-index:100000000;
}

#plDebug .panelContent > div {
	border-bottom:1px solid #ddd;
}

#plDebug .plDebugPanelTitle {
	position:absolute;
	background-color:#ffc;
	color:#666;
	padding-left:20px;
	top:0;
	right:0;
	left:0;
	height:50px;
}

#plDebug .plDebugPanelContent {
	position:absolute;
	top:50px;
	right:0;
	bottom:0;
	left:0;
	height:auto;
	padding:0 0 0 20px;
}

#plDebug .plDebugPanelContent .scroll {
	height:100%;
	overflow:auto;
	display:block;
	padding:0 10px 0 0;
}

#plDebug h3 {
	font-size:24px;
	font-weight:normal;
	line-height:50px;
}

#plDebug h4 {
	font-size:20px;
	font-weight:bold;
	margin-top:0.8em;
}

#plDebug .panelContent table {
	border:1px solid #ccc;
	border-collapse:collapse;
	width:100%;
	background-color:#fff;
	margin-top:0.8em;
	overflow: auto;
}
#plDebug .panelContent tbody td,
#plDebug .panelContent tbody th {
	vertical-align:top;
	padding:2px 3px;
}
#plDebug .panelContent thead th {
	padding:1px 6px 1px 3px;
	text-align:left;
	font-weight:bold;
	font-size:14px;
}
#plDebug .panelContent tbody th {
	width:12em;
	text-align:right;
	color:#666;
	padding-right:.5em;
}

#plDebug .panelContent code {
	font-family:Consolas, Monaco, "Bitstream Vera Sans Mono", "Lucida Console", monospace;
}
/*
#plDebug .panelContent p a:hover, #plDebug .panelContent dd a:hover {
	color:#111;
	background-color:#ffc;
}

#plDebug .panelContent p {
	padding:0 5px;
}

#plDebug .panelContent p, #plDebug .panelContent table, #plDebug .panelContent ol, #plDebug .panelContent ul, #plDebug .panelContent dl {
	margin:5px 0 15px;
	background-color:#fff;
}
#plDebug .panelContent table {
	clear:both;
	border:0;
	padding:0;
	margin:0;
	border-collapse:collapse;
	border-spacing:0;
}

#plDebug .panelContent table a {
	color:#000;
	padding:2px 4px;
}
#plDebug .panelContent table a:hover {
	background-color:#ffc;
}

#plDebug .panelContent table th {
	background-color:#333;
	font-weight:bold;
	color:#fff;
	padding:3px 7px 3px;
	text-align:left;
	cursor:pointer;
}
#plDebug .panelContent table td {
	padding:5px 10px;
	font-size:14px;
	background:#fff;
	color:#000;
	vertical-align:top;
	border:0;
}
#plDebug .panelContent table tr.plDebugOdd td {
  background:#eee;
}
*/

#plDebug .panelContent .plDebugClose {
	text-indent:-9999999px;
	display:block;
	position:absolute;
	top:4px;
	right:15px;
	height:40px;
	width:40px;
	background:url(close.png) no-repeat center center;
}

#plDebug .panelContent .plDebugClose:hover {
	background-image:url(close_hover.png);
}

#plDebug .panelContent .plDebugClose.plDebugBack {
	background-image:url(back.png);
}

#plDebug .panelContent .plDebugClose.plDebugBack:hover  {
	background-image:url(back_hover.png);
}

#plDebug .panelContent dt, #plDebug .panelContent dd {
	display:block;
}

#plDebug .panelContent dt {
	margin-top:0.75em;
}

#plDebug .panelContent dd {
	margin-left:10px;
}

#plDebug a.toggleTemplate {
	padding:4px;
	background-color:#bbb;
	-moz-border-radius:3px;
	-webkit-border-radius:3px;
}

#plDebug a.toggleTemplate:hover {
	padding:4px;
	background-color:#444;
	color:#ffe761;
	-moz-border-radius:3px;
	-webkit-border-radius:3px;
}


#plDebug a.plTemplateShowContext, #plDebug a.plTemplateShowContext span.toggleArrow {
	color:#999;
}

#plDebug a.plTemplateShowContext:hover,  #plDebug a.plTemplateShowContext:hover span.toggleArrow {
	color:#000;
	cursor:pointer;
}

#plDebug .plDebugSqlWrap {
	position:relative;
}

#plDebug .plDebugSql {
	z-index:100000002;
}

#plDebug .plSQLHideStacktraceDiv tbody th {
	text-align: left;
}

#plDebug span.plDebugLineChart {
	border-top:3px solid #777;
	position:absolute;
	bottom:0;
	top:0;
	left:0;
	display:block;
	z-index:1000000001;
}
#plDebug span.plDebugLineChartWarning {
	border-top-color:#900;
}

#plDebug .highlight  { color:#000; }
#plDebug .highlight .err { color:#000; } /* Error */
#plDebug .highlight .g { color:#000; } /* Generic */
#plDebug .highlight .k { color:#000; font-weight:bold } /* Keyword */
#plDebug .highlight .o { color:#000; } /* Operator */
#plDebug .highlight .n { color:#000; } /* Name */
#plDebug .highlight .mi { color:#000; font-weight:bold } /* Literal.Number.Integer */
#plDebug .highlight .l { color:#000; } /* Literal */
#plDebug .highlight .x { color:#000; } /* Other */
#plDebug .highlight .p { color:#000; } /* Punctuation */
#plDebug .highlight .m { color:#000; font-weight:bold } /* Literal.Number */
#plDebug .highlight .s { color:#333 } /* Literal.String */
#plDebug .highlight .w { color:#888888 } /* Text.Whitespace */
#plDebug .highlight .il { color:#000; font-weight:bold } /* Literal.Number.Integer.Long */
#plDebug .highlight .na { color:#333 } /* Name.Attribute */
#plDebug .highlight .nt { color:#000; font-weight:bold } /* Name.Tag */
#plDebug .highlight .nv { color:#333 } /* Name.Variable */
#plDebug .highlight .s2 { color:#333 } /* Literal.String.Double */
#plDebug .highlight .cp { color:#333 } /* Comment.Preproc */
